Tutorials
=========

Here are some simple tutorials, increasing in complexity, of how Bayesian inference may be used in the analysis of some data. 

Some of these were heavily inspired by the tutorial paper of `Hogg, Bovy, and Lang`_ so for more information we recommend that. 
If you want to go even deeper, then check out `Information Theory, Inference, and Learning Algorithms`_ from David MacKay. 

1. `Maximum likelihood`_
2. `Input Functions`_
3. `Markov chain Monte Carlo`_
4. `Using distributions`_
5. `Nested Sampling`_
6. `Custom priors`_


.. toctree::
   :hidden:
   :maxdepth: 2

   max_likelihood
   input_functions
   mcmc
   using_distributions
   nested_sampling
   custom_priors


.. _Hogg, Bovy, and Lang: https://arxiv.org/abs/1008.4686
.. _Information Theory, Inference, and Learning Algorithms: https://www.inference.org.uk/itprnn/book.pdf
.. _Maximum likelihood: ./max_likelihood.html
.. _Input functions: ./input_functions.html
.. _Markov chain Monte Carlo: ./mcmc.html
.. _Nested Sampling: ./nested_sampling.html
.. _Custom priors: ./custom_priors.html
.. _Using distributions: ./using_distributions.html
